==> cdk-cloudformation-newrelic-observability-workloads-1.0.0a5.tar.gz: cdk-cloudformation-newrelic-observability-workloads-1.0.0a5/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-cloudformation-newrelic-observability-workloads",
    "version": "1.0.0.a5",
    "description": "CRUD operations for New Relic Workloads via the NerdGraph API",
    "license": "Apache-2.0",
    "url": "https://github.com/newrelic-experimental/newrelic-cloudformation-resource-providers-workloads",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/cdklabs/cdk-cloudformation.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_cloudformation_newrelic_observability_workloads",
        "cdk_cloudformation_newrelic_observability_workloads._jsii"
    ],
    "package_data": {
        "cdk_cloudformation_newrelic_observability_workloads._jsii": [
            "newrelic-observability-workloads@1.0.0-alpha.5.jsii.tgz"
        ],
        "cdk_cloudformation_newrelic_observability_workloads": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.63.0, <3.0.0",
        "constructs>=10.1.238, <11.0.0",
        "jsii>=1.74.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cdk-cloudformation-newrelic-observability-workloads-1.0.1a7.tar.gz: cdk-cloudformation-newrelic-observability-workloads-1.0.1a7/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-cloudformation-newrelic-observability-workloads",
    "version": "1.0.1.a7",
    "description": "CRUD operations for New Relic Workloads via the NerdGraph API",
    "license": "Apache-2.0",
    "url": "https://github.com/newrelic/newrelic-cloudformation-resource-providers-workloads",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/cdklabs/cdk-cloudformation.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_cloudformation_newrelic_observability_workloads",
        "cdk_cloudformation_newrelic_observability_workloads._jsii"
    ],
    "package_data": {
        "cdk_cloudformation_newrelic_observability_workloads._jsii": [
            "newrelic-observability-workloads@1.0.1-alpha.7.jsii.tgz"
        ],
        "cdk_cloudformation_newrelic_observability_workloads": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.113.0, <3.0.0",
        "constructs>=10.3.0, <11.0.0",
        "jsii>=1.92.0, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
